//
//  RunProcessUseCaseTests.swift
//  UnitTests
//
//  Created by Javier Cicchelli on 05/10/2024.
//  Copyright © 2024 Röck+Cöde. All rights reserved.
//

import Testing

@testable import Piper

struct RunProcessUseCaseTests {
    
    // MARK: Functions tests
    
    @Test("Run a simple process without arguments")
    func simpleCommand_withoutArguments() async throws {
        // GIVEN
        let useCase = RunProcessUseCase(path: .ls)
        
        // WHEN
        let output = try await useCase()
        
        // THEN
        #expect(output.isEmpty == false)
    }
    
    @Test("Run a simple process with arguments")
    func simpleCommand_withArguments() async throws {
        // GIVEN
        let useCase = RunProcessUseCase(
            path: .ls,
            arguments: ["-la", "."]
        )

        // WHEN
        let output = try await useCase()
        
        // THEN
        #expect(output.isEmpty == false)
    }
    
    @Test("Run a simple command with arguments that throws an error")
    func simpleCommand_withArguments_throwsError() async throws {
        // GIVEN
        let useCase = RunProcessUseCase(
            path: .ls,
            arguments: ["-la", "~"]
        )
        
        // WHEN
        // THEN
        await #expect(throws: RunProcessError.self) {
            try await useCase()
        }
    }
    
}

// MARK: - String+Constants

private extension String {
    
    // MARK: Constants
    
    static let ls = "/bin/ls"
    
}
